@@ -1,8 +1,8 @@
 /*
  *  Boa, an http server
  *  Copyright (C) 1995 Paul Phillips <psp@well.com>
- *  Some changes Copyright (C) 1996,97 Larry Doolittle <ldoolitt@jlab.org>
- *  Some changes Copyright (C) 1997 Jon Nelson <nels0988@tc.umn.edu>
+ *  Some changes Copyright (C) 1996-99 Larry Doolittle <ldoolitt@jlab.org>
+ *  Some changes Copyright (C) 1997-99 Jon Nelson <jnelson@boa.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,46 +20,39 @@
  *
  */
 
+/* $Id: boa.h,v 1.43 2000/04/10 19:45:10 jon Exp $*/
+
 #ifndef _BOA_H
 #define _BOA_H
 
+#include "config.h"
+/* config.h should be 1st include because this sets lots of #defines that
+ are used in other header files
+ */
+
+#include "compat.h"             /* oh what fun is porting */
 #include "defines.h"
 #include "globals.h"
 
 #include <errno.h>
-#include <fcntl.h>
-#include <limits.h>				/* OPEN_MAX */
-#include <netinet/in.h>			/* sockaddr_in, sockaddr */
-#include <stdlib.h>				/* malloc, free, etc. */
-#include <stdio.h>				/* stdin, stdout, stderr */
-#include <string.h>				/* strdup */
-#include <time.h>				/* localtime, time */
+#include <stdlib.h>             /* malloc, free, etc. */
+#include <stdio.h>              /* stdin, stdout, stderr */
+#include <string.h>             /* strdup */
+#include <ctype.h>
+#include <time.h>               /* localtime, time */
 #include <pwd.h>
 
-#include <arpa/inet.h>			/* inet_ntoa */
-
-#include <unistd.h>
-#include <sys/mman.h>			/* mmap */
-#include <sys/time.h>			/* select */
-#include <sys/resource.h>		/* setrlimit */
-#include <sys/types.h>			/* socket, bind, accept */
-#include <sys/socket.h>			/* socket, bind, accept, setsockopt, */
-#include <sys/stat.h>			/* open */
-
-#include "compat.h"				/* oh what fun is porting */
+#include <sys/types.h>          /* socket, bind, accept */
+#include <sys/socket.h>         /* socket, bind, accept, setsockopt, */
+#include <sys/stat.h>           /* open */
 
 /* alias */
 
 void add_alias(char *fakename, char *realname, int script);
 int translate_uri(request * req);
-int init_script_alias(request * req, alias * current);
+int init_script_alias(request * req, alias * current, int uri_len);
 void dump_alias(void);
 
-/* boa */
-
-void die(int exit_code);
-void fdset_update(void);
-
 /* config */
 
 void read_config_files(void);
@@ -72,7 +65,6 @@ int get_dir(request * req, struct stat *statbuf);
 
 /* hash */
 
-void add_mime_type(char *extension, char *type);
 int get_mime_hash_value(char *extension);
 char *get_mime_type(char *filename);
 char *get_home_dir(char *name);
@@ -84,9 +76,10 @@ void dump_passwd(void);
 void open_logs(void);
 void close_access_log(void);
 void log_access(request * req);
-void log_error_time(void);
 void log_error_doc(request * req);
 void boa_perror(request * req, char *message);
+void log_error_time(void);
+void log_error_mesg(char *file, int line, char *mesg);
 
 /* queue */
 
@@ -104,8 +97,7 @@ int write_body(request * req);
 /* request */
 
 request *new_request(void);
-void get_request(void);
-void free_request(request ** list_head_addr, request * req);
+void get_request(int);
 void process_requests(void);
 int process_header_end(request * req);
 int process_header_line(request * req);
@@ -116,22 +108,23 @@ void free_requests(void);
 
 /* response */
 
+void print_ka_phrase(request * req);
 void print_content_type(request * req);
 void print_content_length(request * req);
 void print_last_modified(request * req);
 void print_http_headers(request * req);
 
-void send_r_request_ok(request * req);	/* 200 */
-void send_redirect_perm(request * req, char *url);	/* 301 */
-void send_redirect_temp(request * req, char *url);	/* 302 */
-void send_r_not_modified(request * req);	/* 304 */
-void send_r_bad_request(request * req);		/* 400 */
-void send_r_unauthorized(request * req, char *name);	/* 401 */
-void send_r_forbidden(request * req);	/* 403 */
-void send_r_not_found(request * req);	/* 404 */
-void send_r_error(request * req);	/* 500 */
-void send_r_not_implemented(request * req);		/* 501 */
-void send_r_bad_version(request * req);		/* 505 */
+void send_r_request_ok(request * req); /* 200 */
+void send_redirect_perm(request * req, char *url); /* 301 */
+void send_redirect_temp(request * req, char *url, char *more_hdr); /* 302 */
+void send_r_not_modified(request * req); /* 304 */
+void send_r_bad_request(request * req); /* 400 */
+void send_r_unauthorized(request * req, char *name); /* 401 */
+void send_r_forbidden(request * req); /* 403 */
+void send_r_not_found(request * req); /* 404 */
+void send_r_error(request * req); /* 500 */
+void send_r_not_implemented(request * req); /* 501 */
+void send_r_bad_version(request * req); /* 505 */
 
 /* cgi */
 
@@ -149,33 +142,44 @@ int init_cgi(request * req);
 void init_signals(void);
 void sighup_run(void);
 void sigchld_run(void);
-void lame_duck_mode_run(void);
-
-/* util */
+void lame_duck_mode_run(int);
 
+/* util.c */
 void clean_pathname(char *pathname);
-int modified_since(time_t * mtime, char *if_modified_since);
-int month2int(char *month);
-char *to_upper(char *str);
-int unescape_uri(char *uri);
-char *escape_uri(char *uri);
-void close_unused_fds(request * head);
-void fixup_server_root(void);
 char *get_commonlog_time(void);
-int req_write_rfc822_time(request *req, time_t s);
+void rfc822_time_buf(char *buf, time_t s);
 char *simple_itoa(int i);
 char *escape_string(char *inp, char *buf);
-int req_write(request *req, char *msg);
-int req_flush(request *req);
+int month2int(char *month);
+int modified_since(time_t * mtime, char *if_modified_since);
+char *to_upper(char *str);
+int unescape_uri(char *uri);
 
-/* cgi_header.c */
-int process_cgi_header(request * req);
-
-/* pipe.c */
-int write_from_pipe(request * req);
-int read_from_pipe(request * req);
+/* buffer */
+int req_write(request * req, char *msg);
+int req_write_escape_http(request * req, char *msg);
+int req_write_escape_html(request * req, char *msg);
+int req_flush(request * req);
+char *escape_uri(char *uri);
 
 /* timestamp.c */
 void timestamp(void);
 
+/* mmap_cache.c */
+struct mmap_entry *find_mmap(int data_fd, struct stat *s);
+void release_mmap(struct mmap_entry *e);
+
+/* sublog.c */
+int open_gen_fd(char *spec);
+int process_cgi_header(request * req);
+
+/* pipe.c */
+int read_from_pipe(request * req);
+int write_from_pipe(request * req);
+
+/* ip.c */
+int bind_server(int server_s, char *server_ip);
+char *ascii_sockaddr(struct SOCKADDR *s, char *dest, int len);
+int net_port(struct SOCKADDR *s);
+
 #endif
